@@ -46,6 +46,11 @@
 
 #define X_EVOLUTION_CLIENT_UID "X-EVOLUTION-CLIENT-UID"
 
+#if !ICAL_CHECK_VERSION(3, 99, 99)
+#define i_cal_duration_as_seconds i_cal_duration_as_int
+#define i_cal_duration_new_from_seconds i_cal_duration_new_from_int
+#endif
+
 struct _ECalendarViewPrivate {
 	/* The calendar model we are monitoring */
 	ECalModel *model;
@@ -547,9 +552,9 @@ e_calendar_view_add_event_sync (ECalModel *model,
 	tt_start = i_cal_time_as_timet (old_dtstart);
 	old_dtend = i_cal_component_get_dtend (icomp);
 	tt_end = i_cal_time_as_timet (old_dtend);
-	ic_dur = i_cal_duration_new_from_int (tt_end - tt_start);
+	ic_dur = i_cal_duration_new_from_seconds (tt_end - tt_start);
 
-	if (i_cal_duration_as_int (ic_dur) > 60 * 60 * 24) {
+	if (i_cal_duration_as_seconds (ic_dur) > 60 * 60 * 24) {
 		/* This is a long event */
 		start_offset = i_cal_time_get_hour (old_dtstart) * 60 + i_cal_time_get_minute (old_dtstart);
 		end_offset = i_cal_time_get_hour (old_dtstart) * 60 + i_cal_time_get_minute (old_dtend);
@@ -569,10 +574,10 @@ e_calendar_view_add_event_sync (ECalModel *model,
 		if (all_day_event) {
 			g_clear_object (&ic_dur);
 			ic_dur = g_object_ref (ic_oneday);
-		} else if (i_cal_duration_as_int (ic_dur) >= 60 * 60 * 24 && !all_day) {
+		} else if (i_cal_duration_as_seconds (ic_dur) >= 60 * 60 * 24 && !all_day) {
 			g_clear_object (&ic_dur);
 			/* copy & paste from top canvas to main canvas */
-			ic_dur = i_cal_duration_new_from_int (time_division * 60);
+			ic_dur = i_cal_duration_new_from_seconds (time_division * 60);
 		}
 
 		if (all_day)
@@ -581,7 +586,7 @@ e_calendar_view_add_event_sync (ECalModel *model,
 			new_dtstart = dtstart;
 	} else {
 		if (i_cal_time_is_date (old_dtstart) && i_cal_time_is_date (old_dtend) &&
-		    i_cal_duration_as_int (ic_dur) == i_cal_duration_as_int (ic_oneday)) {
+		    i_cal_duration_as_seconds (ic_dur) == i_cal_duration_as_seconds (ic_oneday)) {
 			all_day_event = TRUE;
 			new_dtstart = dtstart;
 		} else {
@@ -605,7 +610,11 @@ e_calendar_view_add_event_sync (ECalModel *model,
 	i_cal_component_set_dtstart (icomp, itime);
 
 	i_cal_time_set_is_date (itime, FALSE);
+	#if ICAL_CHECK_VERSION(3, 99, 99)
+	btime = i_cal_duration_extend (itime, ic_dur);
+	#else
 	btime = i_cal_time_add (itime, ic_dur);
+	#endif
 	if (all_day_event)
 		i_cal_time_set_is_date (btime, TRUE);
 	i_cal_component_set_dtend (icomp, btime);
